Chapter 8: Regression and Model Fitting
---------------------------------------
This chapter covers linear and nonlinear regression and model fitting,
including strategies which are robust to data error and the presence of
outliers.
